@@ -114,6 +114,26 @@ class CaptchaKiller:
         
         response = _send_request(self, url, queryparams, {})
         
+        if 'error' in response:
+            response.update({"success": False})
+            return response
+        elif 'result' in response:
+            response.update({"success": True})
+            return response
+        else:
+            response.update({"success": False})
+            return {"errorId":0, "error": "Unknown error"}
+    def mtcaptcha(self, sitekey, site, action=None):
+        url = self.SOLVE_ENDPOINT + 'solvemtc'
+        
+        queryparams = {
+            'sitekey': sitekey,
+            'site': site,
+            'action': action,
+        }
+        
+        response = _send_request(self, url, queryparams, {})
+        
         if 'error' in response:
             response.update({"success": False})
             return response
